[Mesa-dev] [PATCH v3 1/9] i965/state: Rename brw_upload_state to brw_upload_render_state

Jordan Justen jordan.l.justen at intel.com
Fri Mar 20 17:28:56 PDT 2015


Signed-off-by: Jordan Justen <jordan.l.justen at intel.com>
Reviewed-by: Kristian Høgsberg <krh at bitplanet.net>
---
 src/mesa/drivers/dri/i965/brw_draw.c         |  7 ++++---
 src/mesa/drivers/dri/i965/brw_state.h        |  2 +-
 src/mesa/drivers/dri/i965/brw_state_upload.c | 12 ++++++------
 3 files changed, 11 insertions(+), 10 deletions(-)

diff --git a/src/mesa/drivers/dri/i965/brw_state.h b/src/mesa/drivers/dri/i965/brw_state.h
index 71210b9..ae5ef1f 100644
--- a/src/mesa/drivers/dri/i965/brw_state.h
+++ b/src/mesa/drivers/dri/i965/brw_state.h
@@ -168,7 +168,7 @@ brw_depthbuffer_format(struct brw_context *brw);
 /***********************************************************************
  * brw_state.c
  */
-void brw_upload_state(struct brw_context *brw);
+void brw_upload_render_state(struct brw_context *brw);
 void brw_clear_dirty_bits(struct brw_context *brw);
 void brw_init_state(struct brw_context *brw);
 void brw_destroy_state(struct brw_context *brw);
diff --git a/src/mesa/drivers/dri/i965/brw_draw.c b/src/mesa/drivers/dri/i965/brw_draw.c
index 2d3de45..9b4d8e0 100644
--- a/src/mesa/drivers/dri/i965/brw_draw.c
+++ b/src/mesa/drivers/dri/i965/brw_draw.c
@@ -430,8 +430,9 @@ static void brw_try_draw_prims( struct gl_context *ctx,
 
    intel_prepare_render(brw);
 
    /* This workaround has to happen outside of brw_upload_state() because it
     * may flush the batchbuffer for a blit, affecting the state flags.
     */
    brw_workaround_depthstencil_alignment(brw, 0);
 
@@ -508,7 +509,7 @@ retry:
        */
       if (brw->state.dirty.brw) {
 	 brw->no_batch_wrap = true;
-	 brw_upload_state(brw);
+	 brw_upload_render_state(brw);
       }
 
       brw_emit_prim(brw, &prims[i], brw->primitive);
@@ -430,8 +430,9 @@ static void brw_try_draw_prims( struct gl_context *ctx,
    intel_prepare_render(brw);
 
-   /* This workaround has to happen outside of brw_upload_state() because it
-    * may flush the batchbuffer for a blit, affecting the state flags.
+   /* This workaround has to happen outside of brw_upload_render_state()
+    * because it may flush the batchbuffer for a blit, affecting the state
+    * flags.
     */
    brw_workaround_depthstencil_alignment(brw, 0);
diff --git a/src/mesa/drivers/dri/i965/brw_state_upload.c b/src/mesa/drivers/dri/i965/brw_state_upload.c
index 1b84859..c0f458b 100644
--- a/src/mesa/drivers/dri/i965/brw_state_upload.c
+++ b/src/mesa/drivers/dri/i965/brw_state_upload.c
@@ -569,7 +569,7 @@ brw_upload_programs(struct brw_context *brw)
 /***********************************************************************
  * Emit all state:
  */
-void brw_upload_state(struct brw_context *brw)
+void brw_upload_render_state(struct brw_context *brw)
 {
    struct gl_context *ctx = &brw->ctx;
    struct brw_state_flags *state = &brw->state.dirty;
@@ -676,11 +676,11 @@ void brw_upload_state(struct brw_context *brw)
 
 /**
  * Clear dirty bits to account for the fact that the state emitted by
  * brw_upload_state() has been committed to the hardware.  This is a separate
  * call from brw_upload_state() because it's possible that after the call to
  * brw_upload_state(), we will discover that we've run out of aperture space,
  * and need to rewind the batch buffer to the state it had before the
  * brw_upload_state() call.
  */
 void
 brw_clear_dirty_bits(struct brw_context *brw)
@@ -676,11 +676,11 @@ void brw_upload_state(struct brw_context *brw)
 /**
  * Clear dirty bits to account for the fact that the state emitted by
- * brw_upload_state() has been committed to the hardware.  This is a separate
- * call from brw_upload_state() because it's possible that after the call to
- * brw_upload_state(), we will discover that we've run out of aperture space,
- * and need to rewind the batch buffer to the state it had before the
- * brw_upload_state() call.
+ * brw_upload_render_state() has been committed to the hardware. This is a
+ * separate call from brw_upload_render_state() because it's possible that
+ * after the call to brw_upload_render_state(), we will discover that we've
+ * run out of aperture space, and need to rewind the batch buffer to the state
+ * it had before the brw_upload_render_state() call.
  */
 void
-- 
2.1.4



More information about the mesa-dev mailing list